@@ -1,3 +1,5 @@
+import sys
+
 from ploomber.cli.parsers import CustomParser
 from ploomber.cli.io import cli_endpoint
 from ploomber.telemetry import telemetry
@@ -7,7 +9,8 @@ import datetime
 @cli_endpoint
 def main():
     start_time = datetime.datetime.now()
-    parser = CustomParser(description='Make a pipeline report')
+    parser = CustomParser(description='Make a pipeline report',
+                          prog='ploomber report')
     with parser:
         parser.add_argument(
             '--output',
@@ -18,5 +21,7 @@ def main():
     dag.to_markup(path=args.output)
     end_time = datetime.datetime.now()
     telemetry.log_api("ploomber_report",
-                      total_runtime=str(end_time - start_time))
+                      total_runtime=str(end_time - start_time),
+                      dag=dag,
+                      metadata={'argv': sys.argv})
     print('Report saved at:', args.output)
