@@ -7,7 +7,8 @@ import datetime
 @cli_endpoint
 def main():
     start_time = datetime.datetime.now()
-    parser = CustomParser(description='Show pipeline status')
+    parser = CustomParser(description='Show pipeline status',
+                          prog='ploomber status')
     with parser:
         # this command has no static args
         pass
@@ -15,4 +16,5 @@ def main():
     print(dag.status())
     end_time = datetime.datetime.now()
     telemetry.log_api("ploomber_status",
-                      total_runtime=str(end_time - start_time))
+                      total_runtime=str(end_time - start_time),
+                      dag=dag)
