@@ -27,6 +27,7 @@ class BaseException(ClickException):
     A subclass of ClickException that adds support for printing error messages
     from chained exceptions
     """
+
     def show(self, file: t.Optional[t.IO] = None) -> None:
         if file is None:
             file = get_text_stderr()
@@ -55,6 +56,12 @@ class DAGBuildEarlyStop(Exception):
     pass
 
 
+class TaskInitializationError(BaseException):
+    """Raised when a task fails to initialize
+    """
+    pass
+
+
 class TaskBuildError(Exception):
     """Raise when a task fails to build
     """
@@ -122,6 +129,7 @@ class DAGCycle(Exception):
     """
     Raised when a DAG is defined with cycles.
     """
+
     def __init__(self):
         error_message = """
         Failed to process DAG because it contains cycles.
@@ -133,6 +141,7 @@ class SpecValidationError(Exception):
     """
     Raised when failing to validate a spec
     """
+
     def __init__(self, errors, model, kwargs):
         self.errors = errors
         self.model = model
@@ -149,6 +158,22 @@ class SpecValidationError(Exception):
         return msg
 
 
+class SQLExecuteError(Exception):
+    """
+    Raised by SQLScript and SQLDump when the .execute method fails
+    """
+
+    def __init__(self, type_, source_code, original):
+        self.type_ = type_
+        self.source_code = source_code
+        self.original = original
+        error_message = ('An error occurred when executing '
+                         f'{type_.__name__} task with '
+                         f'source code:\n\n{source_code}\n\n'
+                         f'Reason: {str(original)}')
+        super().__init__(error_message)
+
+
 class RemoteFileNotFound(Exception):
     """
     Raised by File clients when atempting to download a file that doesn't exist
