@@ -1,3 +1,5 @@
+import click
+
 from ploomber.scaffold.scaffoldloader import ScaffoldLoader
 from ploomber.util.util import add_to_sys_path
 from ploomber.util import loader
@@ -15,8 +17,16 @@ def load_dag():
 
 def add(spec, path_to_spec):
     """Add scaffold templates for tasks whose source does not exist
+
+    Parameters
+    ----------
+    spec : DAGSpec
+        The spec to inspect to create missing task.source
+
+    path_to_spec : str
+        Path to the spec, only used to emit messages to the console
     """
-    loader = ScaffoldLoader('ploomber_add')
+    loader = ScaffoldLoader()
 
     # TODO: when the dag has a source loader, the argument passed to
     # ploomber_add should take that into account to place the new file
@@ -32,15 +42,25 @@ def add(spec, path_to_spec):
     # initialized with a path for a file that does not exist
 
     if path_to_spec:
-        print('Found spec at {}'.format(path_to_spec))
+        click.echo(f'Found spec at {str(path_to_spec)!r}')
+
+        n = 0
 
         # make sure current working dir is in the path, otherwise we might not
         # be able to import the PythonCallable functions, which we need to do
         # to locate the modules
         with add_to_sys_path(path_to_spec, chdir=False):
             for task in spec['tasks']:
-                loader.create(source=task['source'],
-                              params=spec['meta'],
-                              class_=task['class'])
+                did_create = loader.create(source=task['source'],
+                                           params=spec['meta'],
+                                           class_=task['class'])
+                n += int(did_create)
+
+        if not n:
+            click.echo(f'All tasks sources declared in {str(path_to_spec)!r} '
+                       'exist, nothing was created.')
+        else:
+            click.echo(f'Created {n} new task sources.')
+
     else:
-        print('Error: No pipeline.yaml spec found...')
+        click.echo('Error: No pipeline.yaml spec found...')
