@@ -4,27 +4,23 @@ from pathlib import Path
 import jupytext
 from jinja2 import Environment, PackageLoader, StrictUndefined
 
-try:
-    import importlib.resources as resources
-except ImportError:
-    import importlib_resources as resources
-
 from ploomber import tasks
 from ploomber.util.dotted_path import (locate_dotted_path,
                                        create_intermediate_modules)
 
 
 class ScaffoldLoader:
-    def __init__(self, directory, project_name=None):
+    """Scaffold task files
+    """
+
+    def __init__(self):
         self.env = Environment(loader=PackageLoader(
-            'ploomber', str(Path('resources', directory))),
+            'ploomber', str(Path('resources', 'ploomber_add'))),
                                variable_start_string='[[',
                                variable_end_string=']]',
                                block_start_string='[%',
                                block_end_string='%]',
                                undefined=StrictUndefined)
-        self.directory = directory
-        self.project_name = project_name
 
     def get_template(self, name):
         return self.env.get_template(name)
@@ -49,15 +45,19 @@ class ScaffoldLoader:
 
         return out
 
-    def copy(self, name):
-        module = '.'.join(['ploomber', 'resources', self.directory])
-        content = resources.read_text(module, name)
-        Path(self.project_name, name).write_text(content)
-
     def create(self, source, params, class_):
+        """Scaffold a task if they don't exist
+
+        Returns
+        -------
+        bool
+            True if it created a task, False if it didn't
+        """
+        did_create = False
+
         if class_ is tasks.PythonCallable:
             source_parts = source.split('.')
-            [*module_parts, fn_name] = source_parts
+            (*module_parts, fn_name) = source_parts
             params['function_name'] = fn_name
 
             try:
@@ -81,19 +81,29 @@ class ScaffoldLoader:
                 print(f'Adding {fn_name!r} to module {source!s}...')
                 fn_str = self.render('function.py', params=params)
                 source.write_text(original + fn_str)
+
+                did_create = True
+
+        #  script task...
         else:
             path = Path(source)
 
             if not path.exists():
-                if path.suffix in {'.py', '.sql', '.ipynb'}:
+                if path.suffix in {'.py', '.sql', '.ipynb', '.R', '.Rmd'}:
                     # create parent folders if needed
                     source.parent.mkdir(parents=True, exist_ok=True)
+
                     content = self.render('task' + source.suffix,
                                           params=params)
+
                     print('Adding {}...'.format(source))
                     source.write_text(content)
+
+                    did_create = True
                 else:
                     print('Error: This command does not support adding '
                           'tasks with extension "{}", valid ones are '
                           '.py and .sql. Skipping {}'.format(
                               path.suffix, path))
+
+        return did_create
